<template>
  <a-card
    :bordered="false"
    title="编码规则"
  >
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form
        layout="inline"
        @keyup.enter.native="searchQuery"
      >
        <a-row :gutter="24">
          <a-col
            :md="6"
            :sm="8"
          >
            <a-form-item label="单据名称">
              <j-input
                placeholder="请输入单据名称查询"
                v-model="queryParam.functionName"
              ></j-input>
            </a-form-item>
          </a-col>
          <a-col
            :md="6"
            :sm="8"
          >
            <a-form-item label="固定字符">
              <j-input
                placeholder="请输入固定字符查询"
                v-model="queryParam.beginSymbol"
              ></j-input>
            </a-form-item>
          </a-col>
          <template v-if="toggleSearchStatus">
          </template>
          <a-col
            :md="6"
            :sm="8"
          >
            <span
              style="float: left;overflow: hidden;"
              class="table-page-search-submitButtons"
            >
              <a-button
                type="primary"
                @click="searchQuery"
                icon="search"
              >查询</a-button>
              <a-button
                type="primary"
                @click="searchReset"
                icon="reload"
                style="margin-left: 8px"
              >重置</a-button>
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>

    <!-- 操作按钮区域 -->
    <div class="table-operator">
      <a-button
        @click="handleAdd"
        type="primary"
        icon="plus"
      >新增</a-button>
      <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-menu slot="overlay">
          <a-menu-item
            key="1"
            @click="batchDel"
          >
            <a-icon type="delete" />删除
          </a-menu-item>
        </a-menu>
        <a-button style="margin-left: 8px">
          批量操作
          <a-icon type="down" />
        </a-button>
      </a-dropdown>
    </div>

    <!-- table区域-begin -->
    <div>
      <div
        class="ant-alert ant-alert-info"
        style="margin-bottom: 16px;"
      >
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择
        <a style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a
          style="margin-left: 24px"
          @click="onClearSelected"
        >清空</a>
      </div>

      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        :columns="columns"
        :rowClassName="tableRowClass"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}"
        @change="handleTableChange"
      >

        <span
          slot="action"
          slot-scope="text, record"
        >
          <a
            href="javascript:;"
            @click="handleDetail(record)"
          >详情</a>

          <a-divider type="vertical" />
          <a-dropdown>
            <a class="ant-dropdown-link">更多
              <a-icon type="down" />
            </a>
            <a-menu slot="overlay">
              <a-menu-item>
                <a @click="handleEdit(record)">编辑</a>
              </a-menu-item>
              <a-menu-item>
                <a-popconfirm
                  title="确定删除吗?"
                  @confirm="() => handleDelete(record.id)"
                >
                  <a>删除</a>
                </a-popconfirm>

              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>
      </a-table>
    </div>

    <!-- 表单区域 -->
    <serial-number-model
      ref="modalForm"
      @ok="modalFormOk"
    ></serial-number-model>
  </a-card>
</template>

<script>
import SerialNumberModel from './modules/SerialNumberModel'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import JDictSelectTag from '@/components/dict/JDictSelectTag'
import { initDictOptions, filterDictText } from '@/components/dict/JDictSelectUtil'
import { requestPut } from '@/api/manage'
import JInput from '@/components/jeecg/JInput'
import JEllipsis from "@/components/jeecg/JEllipsis";

export default {
  name: 'SerialNumberList',
  mixins: [JeecgListMixin],
  components: {
    SerialNumberModel,
    JDictSelectTag,
    JInput,
    JEllipsis,
  },
  data() {
    return {
      isorter: {
        column: 'createTime',
        order: 'desc',
      },
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          align: 'center',
          customRender: function (t, r, index) {
            return parseInt(index) + 1
          },
          width: 50,
        },
        {
          title: '单据名称',
          align: 'center',
          dataIndex: 'functionName',
          sorter: true,
        },
        {
          title: '固定字符',
          align: 'center',
          dataIndex: 'beginSymbol',
          sorter: true,
        },
        {
          title: '企业代码',
          align: 'center',
          dataIndex: 'enterpriseCode',
          sorter: true,
        },
        {
          title: '类型',
          align: 'center',
          dataIndex: 'type',
          sorter: true,
        },
        // {
        //   title: '创建时间',
        //   align: 'center',
        //   dataIndex: 'createTime',
        //   scopedSlots: {
        //     customRender: 'createTime',
        //   },
        //   sorter: true,
        // },
        // {
        //   title: '创建人',
        //   align: 'center',
        //   dataIndex: 'createBy',
        //   scopedSlots: {
        //     customRender: 'createBy',
        //   },
        //   sorter: true,
        // },
        // {
        //   title: '状态',
        //   align: 'center',
        //   scopedSlots: {
        //     customRender: 'status',
        //   },
        //   dataIndex: 'status',
        //   sorter: true,
        //   width: 100,
        // },
        {

          title: '操作',
          align: 'center',
          dataIndex: 'action',
          scopedSlots: {
            customRender: 'action',
          },
          width: 150,
        },

      ],
      url: {
        list: '/eam/serialNumber/list',
        delete: '/eam/serialNumber/delete',
      },
    }
  },
  methods: {

    //禁用状态样式
    tableRowClass(record, index) {
      // if (record.status != "1") {
      // return "frozenRowClass";
      // }
      // return "";
    },


    searchReset() {
      this.queryParam = {};
      this.loadData(1);
    },

  },
  computed: {
    importExcelUrl: function () {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`
    }
  }
}
</script>
<style>
@import '~@assets/less/common.less';
.frozenRowClass {
  color: #c9c9c9;
}
.success {
  color: green;
}
.error {
  color: red;
}
.fontweight {
  font-weight: bold;
}
</style>